pub enum PortableNodeKind {
Show 23 variants
HorizontalBox,
VerticalBox,
Rule,
Insertion,
Mark,
Adjustment,
Ligature,
Discretionary,
OutputWhatsit,
Whatsit,
Math,
Glue,
Kern,
Penalty,
UnsetBox,
Noad(PortableNoadKind),
Style,
Choice,
Character,
NativeWord,
NativeGlyph,
HostBoxRef,
Unknown(i32),
}Expand description
What a node in engine memory is.
Variants
HorizontalBox
An hlist box.
VerticalBox
A vlist box.
Rule
A rule.
Insertion
An insertion.
Mark
A mark.
Adjustment
A \vadjust.
Ligature
A ligature, its original characters are the snapshot’s list.
Discretionary
A discretionary.
OutputWhatsit
An \openout, \write, \closeout or \special whatsit.
Whatsit
Any other whatsit.
Math
A math on or off node, its width is \mathsurround.
Glue
Glue, with a leader box when it is a leader.
Kern
A kern.
Penalty
A penalty.
UnsetBox
An unset box of an alignment still being built.
Noad(PortableNoadKind)
A math noad.
Style
A math style change.
Choice
A \mathchoice.
Character
A character of a TFM font.
NativeWord
A native word.
NativeGlyph
A single native glyph.
HostBoxRef
A resolved host box marker, its character is the host box record id.
Unknown(i32)
A node type this engine does not name.