pub struct PortableNodeSnapshot {Show 21 fields
pub handle: PortableNodeHandle,
pub kind: PortableNodeKind,
pub subtype: i32,
pub source: Option<PortableSourceSpan>,
pub link: Option<PortableNodeHandle>,
pub font: i32,
pub character: i32,
pub width: i32,
pub height: i32,
pub depth: i32,
pub shift: i32,
pub list: Option<PortableNodeHandle>,
pub leader: Option<PortableNodeHandle>,
pub native_glyphs: Vec<PortableNativeGlyph>,
pub glue_set: f64,
pub glue_sign: i32,
pub glue_order: i32,
pub glue_stretch: i32,
pub glue_shrink: i32,
pub glue_stretch_order: i32,
pub glue_shrink_order: i32,
}Expand description
A read only copy of one node’s fields, dimensions in scaled points.
Fields
handle: PortableNodeHandleThe node.
kind: PortableNodeKindWhat the node is.
subtype: i32The raw subtype byte, the span count of an unset box.
source: Option<PortableSourceSpan>Where the node came from when source tracking is on.
link: Option<PortableNodeHandle>The next node in its list.
font: i32Font of a character, ligature, native word or native glyph.
character: i32Character of a character or ligature, glyph of a native glyph, record id of a host box marker.
width: i32Width, the natural width of glue and the surround of a math node.
height: i32Height.
depth: i32Depth.
shift: i32Shift of a box.
list: Option<PortableNodeHandle>Contents of a box, or the original characters of a ligature.
leader: Option<PortableNodeHandle>Leader box or rule of leader glue.
native_glyphs: Vec<PortableNativeGlyph>Shaped glyphs of a native word or glyph.
glue_set: f64Box glue set ratio from hpack or vpack.
glue_sign: i32Box glue sign: 0 normal, 1 stretching, 2 shrinking.
glue_order: i32Box glue order that stretches or shrinks.
glue_stretch: i32Stretch of glue or of an unset box.
glue_shrink: i32Shrink of glue or of an unset box.
glue_stretch_order: i32Order of the stretch of glue or of an unset box.
glue_shrink_order: i32Order of the shrink of glue or of an unset box.